#ifndef NT2_INCLUDE_CONSTANTS_MLOGEPS2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MLOGEPS2_HPP_INCLUDED

#include <nt2/constant/include/constants/mlogeps2.hpp>

#endif
